==> cloud-5.1.1.tar.gz: cloud/modules/cloud_dashboard/cloud_dashboard/src/constant/templates/form/openstack/project.ts <==
import EntityFormTemplate from 'model/EntityFormTemplate';

const OPENSTACK_PROJECT_TEMPLATE: EntityFormTemplate[] = [
  {
    cloudServiceProvider: 'openstack',
    entityName: 'project',
    actionType: 'create',
    entityRecords: [
      {
        type: 'panel',
        panelName: 'Project',
        keyValueRecords: [
          { type: 'default', labelName: 'Name', name: 'name', defaultValue: '', required: true },
          { type: 'textarea', labelName: 'Description', name: 'description', defaultValue: '' },
          { type: 'boolean', labelName: 'Enabled', name: 'enabled', defaultValue: true },
        ]
      }
    ]
  },
  {
    cloudServiceProvider: 'openstack',
    entityName: 'project',
    actionType: 'edit',
    entityRecords: [
      {
        type: 'panel',
        panelName: 'Project',
        keyValueRecords: [
          { type: 'default', labelName: 'Name', name: 'name', defaultValue: '', required: true },
          { type: 'textarea', labelName: 'Description', name: 'description', defaultValue: '' },
          { type: 'boolean', labelName: 'Enabled', name: 'enabled', defaultValue: true },
        ]
      },
      {
        type: 'panel',
        panelName: 'User Roles',
        keyValueRecords: [
          { type: 'item-array', labelName: 'User Roles', name: 'user_roles', defaultValue: [], info: [
            { labelName: 'User', name: 'user', type: 'join', entityTypeId: 'openstack_user' },
            { labelName: 'Role', name: 'roles', type: 'multi-select', entityTypeId: 'openstack_role' },
            ] }
        ]
      }
    ]
  },
  {
    cloudServiceProvider: 'openstack',
    entityName: 'project',
    actionType: 'delete',
    entityRecords: [
      {
        type: 'label',
        text: 'Are you sure you want to delete the {{entityName}} {{name}}?'
      },
    ],
    submitButtonLabel: 'Delete'
  }
]

export default OPENSTACK_PROJECT_TEMPLATE;

==> cloud-5.5.0.tar.gz: cloud/modules/cloud_dashboard/cloud_dashboard/src/constant/templates/form/openstack/project.ts <==
import EntityFormTemplate from 'model/EntityFormTemplate';

const OPENSTACK_PROJECT_TEMPLATE: EntityFormTemplate[] = [
  {
    cloudServiceProvider: 'openstack',
    entityName: 'project',
    actionType: 'create',
    entityRecords: [
      {
        type: 'panel',
        panelName: 'Project',
        keyValueRecords: [
          { type: 'default', labelName: 'Name', name: 'name', defaultValue: '', required: true, id: 'field--name-name', class: 'field--name-name' },
          { type: 'textarea', labelName: 'Description', name: 'description', defaultValue: '' },
          { type: 'boolean', labelName: 'Enabled', name: 'enabled', defaultValue: true },
        ]
      }
    ]
  },
  {
    cloudServiceProvider: 'openstack',
    entityName: 'project',
    actionType: 'edit',
    entityRecords: [
      {
        type: 'panel',
        panelName: 'Project',
        keyValueRecords: [
          { type: 'default', labelName: 'Name', name: 'name', defaultValue: '', required: true, id: 'field--name-name', class: 'field--name-name' },
          { type: 'textarea', labelName: 'Description', name: 'description', defaultValue: '' },
          { type: 'boolean', labelName: 'Enabled', name: 'enabled', defaultValue: true },
        ]
      },
      {
        type: 'panel',
        panelName: 'User Roles',
        keyValueRecords: [
          { type: 'item-array', labelName: 'User Roles', name: 'user_roles', defaultValue: [], info: [
            { labelName: 'User', name: 'user', type: 'join', entityTypeId: 'openstack_user' },
            { labelName: 'Role', name: 'roles', type: 'multi-select', entityTypeId: 'openstack_role' },
            ] }
        ]
      }
    ]
  },
  {
    cloudServiceProvider: 'openstack',
    entityName: 'project',
    actionType: 'delete',
    entityRecords: [
      {
        type: 'label',
        text: 'This action cannot be undone.'
      },
    ],
    submitButtonLabel: 'Delete'
  }
]

export default OPENSTACK_PROJECT_TEMPLATE;
